Class: PaypalServerSdk::OrderApplicationContextShippingPreference

Inherits:
Object
  • Object
show all
Defined in:
lib/paypal_server_sdk/models/order_application_context_shipping_preference.rb

Overview

DEPRECATED. DEPRECATED. The shipping preference: Displays the shipping address to the customer. Enables the customer to choose an address on the PayPal site. Restricts the customer from changing the address during the payment-approval process. . The fields in application_context are now available in the experience_context object under the payment_source which supports them (eg. payment_source.paypal.experience_context.shipping_preference). Please specify this field in the experience_context object instead of the application_context object., The shipping preference. This only applies to PayPal payment source., The shipping preference. This only applies to PayPal payment source.

Constant Summary collapse

ORDER_APPLICATION_CONTEXT_SHIPPING_PREFERENCE =
[
  # Use the customer-provided shipping address on the PayPal site.

  GET_FROM_FILE = 'GET_FROM_FILE'.freeze,

  # Redact the shipping address from the PayPal site. Recommended for

  # digital goods.

  NO_SHIPPING = 'NO_SHIPPING'.freeze,

  # Use the merchant-provided address. The customer cannot change this

  # address on the PayPal site.

  SET_PROVIDED_ADDRESS = 'SET_PROVIDED_ADDRESS'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.validate(value) ⇒ Object



32
33
34
35
36
# File 'lib/paypal_server_sdk/models/order_application_context_shipping_preference.rb', line 32

def self.validate(value)
  return false if value.nil?

  true
end