Class: PaypalServerSdk::OrderStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/paypal_server_sdk/models/order_status.rb

Overview

The order status.

Constant Summary collapse

ORDER_STATUS =
[
  # The order was created with the specified context.
  CREATED = 'CREATED'.freeze,

  # The order was saved and persisted. The order status continues to be in
  # progress until a capture is made with final_capture = true for all
  # purchase units within the order.
  SAVED = 'SAVED'.freeze,

  # The customer approved the payment through the PayPal wallet or another
  # form of guest or unbranded payment. For example, a card, bank account,
  # or so on.
  APPROVED = 'APPROVED'.freeze,

  # All purchase units in the order are voided.
  VOIDED = 'VOIDED'.freeze,

  # The intent of the order was completed and a `payments` resource was
  # created. Important: Check the payment status in
  # `purchase_units[].payments.captures[].status` before fulfilling the
  # order. A completed order can indicate a payment was authorized, an
  # authorized payment was captured, or a payment was declined.
  COMPLETED = 'COMPLETED'.freeze,

  # The order requires an action from the payer (e.g. 3DS authentication).
  # Redirect the payer to the "rel":"payer-action" HATEOAS link returned as
  # part of the response prior to authorizing or capturing the order. Some
  # payment sources may not return a payer-action HATEOAS link (eg. MB WAY).
  # For these payment sources the payer-action is managed by the scheme
  # itself (eg. through SMS, email, in-app notification, etc).
  PAYER_ACTION_REQUIRED = 'PAYER_ACTION_REQUIRED'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.from_value(value, default_value = CREATED) ⇒ Object



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/paypal_server_sdk/models/order_status.rb', line 48

def self.from_value(value, default_value = CREATED)
  return default_value if value.nil?

  str = value.to_s.strip

  case str.downcase
  when 'created' then CREATED
  when 'saved' then SAVED
  when 'approved' then APPROVED
  when 'voided' then VOIDED
  when 'completed' then COMPLETED
  when 'payer_action_required' then PAYER_ACTION_REQUIRED
  else
    default_value
  end
end

.validate(value) ⇒ Object



42
43
44
45
46
# File 'lib/paypal_server_sdk/models/order_status.rb', line 42

def self.validate(value)
  return false if value.nil?

  true
end