Class: PaypalServerSdk::OrderTrackerStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/paypal_server_sdk/models/order_tracker_status.rb

Overview

The status of the item shipment.

Constant Summary collapse

ORDER_TRACKER_STATUS =
[
  # The shipment was cancelled and the tracking number no longer applies.

  CANCELLED = 'CANCELLED'.freeze,

  # The merchant has assigned a tracking number to the items being shipped

  # from the Order. This does not correspond to the carrier's actual status

  # for the shipment. The latest status of the parcel must be retrieved from

  # the carrier.

  SHIPPED = 'SHIPPED'.freeze
].freeze

Class Method Summary collapse

Class Method Details

.validate(value) ⇒ Object



20
21
22
23
24
# File 'lib/paypal_server_sdk/models/order_tracker_status.rb', line 20

def self.validate(value)
  return false if value.nil?

  true
end